@@ -7,12 +7,7 @@ pub fn main() -> Result<(), io::Error> {
     let mut mycobot = MyCobotSerialOperator::new(&args[0], 115200);
     let target = vec![0.0, 0.0, 0.0, 0.0, 50.0, 0.0];
     mycobot.set_color(255, 0, 0)?;
-    mycobot.send_angles(&target, 50)?;
-    loop {
-        if mycobot.is_in_angle_position(&target)? == 1 {
-            break;
-        }
-    }
+    mycobot.sync_send_angles(&target, 50, 10.0)?;
     let angles = mycobot.get_angles()?;
     println!("Angles: {:?}", angles);
     mycobot.set_color(0, 255, 0)?;
